use clap::Subcommand;

#[derive(Subcommand)]
pub enum Command {
    /// Add devices of a specific user to the same sync group
    Sync {
        username: String,
        devices: Vec<String>,
    },
    /// List the devices for the given user
    Devices { username: String },
}

impl Command {
    pub fn run(&self, config: &crate::config::Config) -> u8 {
        let store =
            gpodder_sqlite::SqliteRepository::from_path(config.data_dir.join(crate::DB_FILENAME))
                .unwrap();
        let store = gpodder::GpodderRepository::new(store);

        match self {
            Self::Sync { username, devices } => {
                let user = store.get_user(&username).unwrap();
                store
                    .update_device_sync_status(
                        &user,
                        vec![devices.iter().map(|s| s.as_ref()).collect()],
                        Vec::new(),
                    )
                    .unwrap();
            }
            Self::Devices { username } => {
                let user = store.get_user(&username).unwrap();
                let devices = store.devices_for_user(&user).unwrap();

                for device in devices {
                    println!("{} ({} subscriptions)", device.id, device.subscriptions);
                }
            }
        }

        0
    }
}
